@@ -43,8 +43,8 @@ unique_ids = {}
 # Json object to store dbt profile(profile.yml) related information
 profile_info = {}
 
-# Json object to store cml environment variables
-cml_info = {}
+# Json object to store dbt deployment environment variables
+dbt_deployment_env_info = {}
 
 def populate_platform_info(cred: Credentials, ver):
     """
@@ -67,21 +67,12 @@ def populate_platform_info(cred: Credentials, ver):
     # dbt adapter info e.g. impala-1.2.0
     platform_info["dbt_adapter"] = f"{cred.type}-{ver.version}"
 
-def populate_cml_info():
+def populate_dbt_deployment_env_info():
     """
-    populate cml environment variables if available to be passed on for tracking
+    populate dbt deployment environment variables if available to be passed on for tracking
     """
-    default_value = ""  # if environment variables doesn't exist add empty string as default
-    cml_info["ml_runtime_edition"] = os.environ.get('ML_RUNTIME_EDITION', default_value)
-    cml_info["ml_runtime_git_hash"] = os.environ.get('ML_RUNTIME_GIT_HASH', default_value)
-    cml_info["ml_runtime_kernel"] = os.environ.get('ML_RUNTIME_KERNEL', default_value)
-    cml_info["ml_runtime_editor"] = os.environ.get('ML_RUNTIME_EDITOR', default_value)
-    cml_info["ml_runtime_gbn"] = os.environ.get('ML_RUNTIME_GBN', default_value)
-    cml_info["ml_runtime_full_version"] = os.environ.get('ML_RUNTIME_FULL_VERSION', default_value)
-    cml_info["ml_runtime_description"] = os.environ.get('ML_RUNTIME_DESCRIPTION', default_value)
-    cml_info["ml_runtime_maintenance_version"] = os.environ.get('ML_RUNTIME_MAINTENANCE_VERSION', default_value)
-    cml_info["ml_runtime_metadata_version"] = os.environ.get('ML_RUNTIME_METADATA_VERSION', default_value)
-
+    default_value = "{}"  # if environment variables doesn't exist add empty json as default
+    dbt_deployment_env_info["dbt_deployment_env"] = json.loads(os.environ.get('DBT_DEPLOYMENT_ENV', default_value))
 
 def populate_unique_ids(cred: Credentials):
     host = str(cred.host).encode()
@@ -89,7 +80,11 @@ def populate_unique_ids(cred: Credentials):
     timestamp = str(time.time()).encode()
 
     # dbt invocation id
-    unique_ids["id"] = active_user.invocation_id
+    if active_user:
+       unique_ids["id"] = active_user.invocation_id
+    else:
+       unique_ids["id"] = "N/A"
+
     # hashed host name
     unique_ids["unique_host_hash"] = hashlib.md5(host).hexdigest()
     # hashed username
@@ -190,11 +185,11 @@ def track_usage(tracking_payload):
     # inject other static payload to tracking_payload
     tracking_payload = _merge_keys(unique_ids, tracking_payload)
     tracking_payload = _merge_keys(platform_info, tracking_payload)
-    tracking_payload = _merge_keys(cml_info, tracking_payload)
+    tracking_payload = _merge_keys(dbt_deployment_env_info, tracking_payload)
     tracking_payload = _merge_keys(profile_info, tracking_payload)
 
     # form the tracking data
-    tracking_data = {"data": tracking_payload}
+    tracking_data = {"data": json.dumps(tracking_payload)}
 
     # inner function which actually calls the endpoint
     def _tracking_func(data):
@@ -223,7 +218,6 @@ def track_usage(tracking_payload):
         res = None
 
         try:
-            logger.debug(f"Sending Event {data}")
             res = requests.post(
                 SNOWPLOW_ENDPOINT, data=data, headers=headers, timeout=SNOWPLOW_TIMEOUT
             )
@@ -234,6 +228,8 @@ def track_usage(tracking_payload):
 
         return res
 
+    logger.debug(f"Sending Event {tracking_data}")
+
     # call the tracking function in a Thread
     the_track_thread = threading.Thread(
         target=_tracking_func, kwargs={"data": tracking_data}
