@@ -398,7 +398,7 @@ class ImpalaAdapter(SQLAdapter):
             # convert ImpalaColumns into catalog dicts
             as_dict = column.to_column_dict()
             
-            as_dict['column_name'] = relation.table + '.' + as_dict.pop('column', None)
+            as_dict['column_name'] = as_dict.pop('column', None)
             as_dict['column_type'] = as_dict.pop('dtype')
             as_dict['table_database'] = None
 
@@ -412,26 +412,101 @@ class ImpalaAdapter(SQLAdapter):
     def debug_query(self) -> None:
         self.execute("select 1 as id")
         username = ""
+
+        # query user permissions where available
         try:
             username = self.config.credentials.username
-            sql_query = "show grant user `" + username + "` on server"
+            if not username: # username is not available when auth_type is insecure or kerberos
+                logger.debug("No username available to fetch permissions")
+                payload = {
+                    "event_type": "dbt_impala_debug_and_fetch_permissions",
+                    "permissions": "NA",
+                }
+                tracker.track_usage(payload)
+            else:
+                sql_query = "show grant user `" + username + "` on server"
+                _, table = self.execute(sql_query, True, True)
+                permissions_object = []
+                json_funcs = [c.jsonify for c in table.column_types]
+
+                for row in table.rows:
+                    values = tuple(json_funcs[i](d) for i, d in enumerate(row))
+                    permissions_object.append(OrderedDict(zip(row.keys(), values)))
+
+                permissions_json = permissions_object
+
+                payload = {
+                    "event_type": "dbt_impala_debug_and_fetch_permissions",
+                    "permissions": permissions_json,
+                }
+                tracker.track_usage(payload)
+        except Exception as ex:
+            logger.error(
+                f"Failed to fetch permissions for user: {username}. Exception: {ex}"
+            )
+            self.connections.get_thread_connection().handle.close()
+
+        # query warehouse version
+        try:
+            sql_query = "select version()"
             _, table = self.execute(sql_query, True, True)
-            permissions_object = []
+            version_object = []
             json_funcs = [c.jsonify for c in table.column_types]
 
             for row in table.rows:
                 values = tuple(json_funcs[i](d) for i, d in enumerate(row))
-                permissions_object.append(OrderedDict(zip(row.keys(), values)))
+                version_object.append(OrderedDict(zip(row.keys(), values)))
 
-            permissions_json = json.dumps(permissions_object)
+            version_json = version_object
 
             payload = {
-                "event_type": "dbt_impala_debug_and_fetch_permissions",
-                "permissions": permissions_json,
+                "event_type": "dbt_impala_warehouse",
+                "warehouse_version": version_json,
             }
             tracker.track_usage(payload)
         except Exception as ex:
-            logger.debug(
-                f"Failed to fetch permissions for user: {username}. Exception: {ex}"
+            logger.error(
+                f"Failed to fetch warehouse version. Exception: {ex}"
             )
-            self.connections.get_thread_connection().handle.close()
+
+        self.connections.get_thread_connection().handle.close()
+
+    ###
+    # Methods about grants
+    ###
+    def standardize_grants_dict(self, grants_table: agate.Table) -> dict:
+        """Translate the result of `show grants` (or equivalent) to match the
+        grants which a user would configure in their project.
+
+        Ideally, the SQL to show grants should also be filtering:
+        filter OUT any grants TO the current user/role (e.g. OWNERSHIP).
+        If that's not possible in SQL, it can be done in this method instead.
+
+        :param grants_table: An agate table containing the query result of
+            the SQL returned by get_show_grant_sql
+        :return: A standardized dictionary matching the `grants` config
+        :rtype: dict
+        """
+        unsupported_privileges = ["INDEX", "READ", "WRITE"]
+
+        grants_dict: Dict[str, List[str]] = {}
+        for row in grants_table:
+            grantee = row["grantor"]
+            privilege = row["privilege"]
+
+            # skip unsupported privileges
+            if privilege in unsupported_privileges:
+                continue
+
+            if privilege in grants_dict.keys():
+                grants_dict[privilege].append(grantee)
+            else:
+                grants_dict.update({privilege: [grantee]})
+        return grants_dict
+
+    def valid_incremental_strategies(self):
+        """The set of standard builtin strategies which this adapter supports out-of-the-box.
+        Not used to validate custom strategies defined by end users.
+        """
+        return ["append", "insert_overwrite"]
+        
\ No newline at end of file
